/*
  Mybotic Lora SX1278 Example
*/
// include the library
#include <LoRaLib.h>

// NSS pin:   10 (4 on ESP32/ESP8266 boards)
// DIO0 pin:  2
// DIO1 pin:  3
SX1278 lora = new LoRa;

#define LED_START 4
#define LED_WAITING 5

void setup() {
  Serial.begin(9600);
  pinMode(LED_START, OUTPUT);
  pinMode(LED_WAITING, OUTPUT);
  // initialize SX1278 with default settings
  Serial.print(F("Initializing ... "));
  // carrier frequency:           434.0 MHz
  // bandwidth:                   125.0 kHz
  // spreading factor:            9
  // coding rate:                 7
  // sync word:                   0x12
  // output power:                17 dBm
  // current limit:               100 mA
  // preamble length:             8 symbols
  // amplifier gain:              0 (automatic gain control)
  int state = lora.begin();
  if (state == ERR_NONE) {
    Serial.println(F("success!"));
  } else {
    Serial.print(F("failed, code "));
    Serial.println(state);
    while (true);
  }
}

void loop() {
  Serial.print("Waiting for incoming transmission ... ");

  // you can receive data as an Arduino String
  String str;
  int state = lora.receive(str);

  // you can also receive data as byte array
  /*
    byte byteArr[8];
    int state = lora.receive(byteArr, 8);
  */

  if (state == ERR_NONE)
  {
    // packet was successfully received
    digitalWrite(LED_START, HIGH);
    digitalWrite(LED_WAITING, LOW);
    Serial.println("success!");

    // print data of the packet
    Serial.print("Data:\t\t\t");
    Serial.println(str);

  }
  else if (state == ERR_RX_TIMEOUT)
  {
    // timeout occurred while waiting for a packet
    digitalWrite(LED_WAITING, HIGH);
    digitalWrite(LED_START, LOW);
    Serial.println("timeout!");

  }
  else if (state == ERR_CRC_MISMATCH)
  {
    // packet was received, but is malformed
    digitalWrite(LED_WAITING, HIGH);
    digitalWrite(LED_START, LOW);
    Serial.println("CRC error!");

  }
  delay(1000);
}

