/*
  Mybotic Lora SX1278 Example
*/

// include the library
#include <LoRaLib.h>

#define BUTTON 4
#define LED_TRANSMIT 6
#define LED_WAITING 5

unsigned long debounce = 200UL;
unsigned long timer1 = 0;

//Button state
int bState = HIGH;
int bpre_press = LOW;
int bcur_press;
int bfinal_State;

// Pin Connection
// NSS pin:   10 (4 on ESP32/ESP8266 boards)
// DIO0 pin:  2
// DIO1 pin:  3
SX1278 lora = new LoRa;

void setup() {
  Serial.begin(9600);
  pinMode(BUTTON, INPUT);
  pinMode(LED_TRANSMIT, OUTPUT);
  pinMode(LED_WAITING, OUTPUT);

  // initialize SX1278 with default settings
  Serial.print(F("Initializing ... "));
  // carrier frequency:           434.0 MHz
  // bandwidth:                   125.0 kHz
  // spreading factor:            9
  // coding rate:                 7
  // sync word:                   0x12
  // output power:                17 dBm
  // current limit:               100 mA
  // preamble length:             8 symbols
  // amplifier gain:              0 (automatic gain control)
  int state = lora.begin();
  if (state == ERR_NONE) {
    Serial.println(F("success!"));
  } else {
    Serial.print(F("failed, code "));
    Serial.println(state);
    while (true);
  }
}

void loop() {
  Serial.print("Sending packet ... ");

  // you can transmit C-string or Arduino string up to
  // 256 characters long
  short button_state = usRead_TOUCH_BUTTON();
  if (button_state == 0)
  {
    digitalWrite (LED_WAITING, LOW);
    digitalWrite (LED_TRANSMIT, HIGH);
    Serial.println("Transmitter On.");
    int state = lora.transmit("Hello World!");
    if (state == ERR_NONE) {
      // the packet was successfully transmitted
      Serial.println(" success!");

    }
    else if (state == ERR_PACKET_TOO_LONG) {
      // the supplied packet was longer than 256 bytes
      Serial.println(" too long!");
    }
    else if (state == ERR_TX_TIMEOUT) {
      // timeout occurred while transmitting packet
      Serial.println(" timeout!");
    }
    delay(500);
  }
  else
  {
    digitalWrite (LED_WAITING, HIGH);
    digitalWrite (LED_TRANSMIT, LOW);
    Serial.println("Transmitter Off.");
    delay(500);
  }
}

unsigned short usRead_TOUCH_BUTTON(void)
{
  bcur_press = digitalRead(BUTTON);

  if (bcur_press == HIGH && bpre_press == LOW && (millis() - timer1) > debounce)
  {
    if (bState == HIGH)
      bState = LOW;
    else
      bState = HIGH;

    timer1 = millis();
  }

  bfinal_State = bState;
  return bfinal_State;
}
